==> web-10.0.0.tgz: package/lib/myTable/table/index.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from "react";
import * as Immutable from "immutable";
import { Empty } from "../../my-icon/index";
import { CheckBox } from "../../input/index";
import { ScrollBox } from "../../scroll/index";
import PageSize from "../../pagezSize/index";
import TabBody from "./TBody";
var checkAllStataus;
(function (checkAllStataus) {
    checkAllStataus["hasChecked"] = "hasCheck";
    checkAllStataus["checked"] = "checked";
    checkAllStataus["noChecked"] = "noChecked";
})(checkAllStataus || (checkAllStataus = {}));
const tableInitData = (data, defaulSel, idField) => {
    const defaulSelArr = `${defaulSel}`.split(",");
    return Immutable.fromJS(data, (_key, val) => {
        if (Immutable.isKeyed(val)) {
            let obj = val.toOrderedMap();
            const id = val.get(idField);
            const has = defaulSelArr.includes(`${id}`);
            obj = obj.set("checked", has).set("selected", has);
            return obj;
        }
        else {
            return val.toList();
        }
    });
};
const initCurPage = (props, perNums, curOptId) => {
    const { data, idField } = props;
    if (!curOptId) {
        return 1;
    }
    else {
        const index = data.findIndex((val) => String(val[idField]) === String(curOptId));
        const pages = index > -1 ? Math.ceil((index + 1) / perNums) : 1;
        return pages;
    }
};
class Table extends React.PureComponent {
    constructor(props) {
        super(props);
        this.fieldObj = this.initFixObj();
        this.tableContainer = React.createRef();
        this.scrollMethod = null;
        this.bindScrollMethods = (methods) => {
            this.scrollMethod = methods;
        };
        this.getSelected = () => {
            const { tableData } = this.state;
            return tableData.filter((val) => val.get("checked"));
        };
        this.checkCurPageAll = (e) => {
            const inpDom = e.currentTarget;
            const checked = inpDom.checked;
            const { tableData, curPage, perNums } = this.state;
            const { noPageNums } = this.props;
            let num;
            if (!noPageNums) {
                const rest = curPage * perNums - tableData.size;
                num = rest > 0 ? perNums - rest : perNums;
            }
            else {
                num = tableData.size;
            }
            this.setState((pre) => {
                let newData = pre.tableData;
                Array.from({ length: num }).forEach((_val, index) => {
                    newData = newData.updateIn([index + (curPage - 1) * perNums], (val) => val.set("checked", checked));
                });
                return {
                    tableData: newData,
                };
            });
        };
        this.changeState = (field, data) => {
            const obj = {
                [field]: data
            };
            if (field === "perNums") {
                obj.curPage = 1;
            }
            this.setState(obj, () => {
                if (["curPage", "perNums"].includes(field) && this.scrollMethod) {
                    this.scrollMethod.initScroll();
                }
            });
        };
        this.selectedHandle = (e) => {
            const index = e.currentTarget.dataset.index;
            const { idField } = this.props;
            this.setState((pre) => {
                const data = pre.tableData;
                const seleted = data.findIndex((val) => val.get("selected"));
                const tableData = seleted === -1
                    ? data.setIn([+index - 1, "selected"], true)
                    : data
                        .setIn([seleted, "selected"], false)
                        .setIn([+index - 1, "selected"], true);
                const curOptId = seleted === -1
                    ? data.getIn([+index - 1, idField])
                    : data.getIn([seleted, idField]);
                return {
                    tableData,
                    curOptId,
                };
            });
        };
        const { data, defaultSel, idField, initSelectVal, bindGetSelectedFn } = props;
        this.state = {
            perNums: 20,
            curPage: initCurPage(props, 20, defaultSel),
            tableData: tableInitData(data, defaultSel, idField),
            preData: data,
            curOptId: defaultSel,
            preInitSelectVal: initSelectVal,
        };
        if (bindGetSelectedFn) {
            bindGetSelectedFn(this.getSelected);
        }
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.data !== preState.preData) {
            const { defaultSel, data, idField } = nextProps;
            const val = preState.curOptId || defaultSel;
            return {
                tableData: tableInitData(data, val, idField),
                curPage: initCurPage(nextProps, preState.perNums, preState.curOptId),
                preData: data,
            };
        }
        if (nextProps.initSelectVal !== preState.preInitSelectVal) {
            const { data, idField, initSelectVal } = nextProps;
            const val = initSelectVal ? initSelectVal.id : "";
            return {
                tableData: tableInitData(data, val, idField),
                preInitSelectVal: initSelectVal,
                curPage: initCurPage(nextProps, preState.perNums, val),
                curOptId: val,
            };
        }
        else {
            return null;
        }
    }
    componentDidMount() {
        const { defaultSel } = this.props;
        if (defaultSel) {
            this.scrollToSeletItem();
        }
    }
    getSnapshotBeforeUpdate(preProps) {
        const { data, initSelectVal } = this.props;
        if (preProps.data !== data || initSelectVal !== preProps.initSelectVal) {
            return true;
        }
        else {
            return null;
        }
    }
    componentDidUpdate(preProps, _preState, snapshot) {
        if (snapshot) {
            const { defaultSel, initSelectVal } = this.props;
            const val = initSelectVal ? initSelectVal.id : defaultSel;
            if (val) {
                this.scrollToSeletItem();
            }
        }
        if (preProps.data !== this.props.data && this.scrollMethod) {
            this.scrollMethod.initScroll();
        }
    }
    initFixObj() {
        const { idField, checkbox, children: arr, tabField, noPageNums, } = this.props;
        const column = arr
            .filter((val) => val)
            .map((val) => {
            const _a = val.props, { children } = _a, obj = __rest(_a, ["children"]);
            return obj;
        });
        return {
            idField,
            checkbox,
            column,
            tabField,
            noPageNums,
        };
    }
    scrollToSeletItem() {
        const item = this.tableContainer.current.querySelector(".selected");
        if (!item) {
            return;
        }
        const top = item.offsetTop - 12;
        window.setTimeout(() => {
            this.scrollMethod.scrollToTop(Math.max(0, top));
        }, 10);
    }
    getColGroupCom() {
        const { column, checkbox } = this.fieldObj;
        const list = column.map(({ width, field }) => {
            let wObj;
            if (width) {
                const unit = `${width}`.includes("%") ? "" : "px";
                wObj = width ? { width: `${width}` + unit } : undefined;
            }
            else {
                wObj = undefined;
            }
            return React.createElement("col", { key: field, style: wObj });
        });
        const orderWid = checkbox ? 80 : 60;
        return (React.createElement("colgroup", null,
            React.createElement("col", { style: { width: orderWid }, key: "order" }),
            list));
    }
    getCurPageData() {
        const { tableData, curPage, perNums } = this.state;
        const { noPageNums } = this.props;
        const startIndex = (curPage - 1) * perNums;
        return !noPageNums
            ? tableData.slice(startIndex, startIndex + perNums)
            : tableData;
    }
    countCurPageTotalStatus() {
        const { tableData } = this.state;
        if (tableData.size === 0) {
            return checkAllStataus.noChecked;
        }
        else {
            const curPageData = this.getCurPageData();
            const allCheck = curPageData.every((val) => val.get("checked"));
            if (allCheck) {
                return checkAllStataus.checked;
            }
            else {
                const hasCheck = curPageData.some((val) => val.get("checked"));
                return hasCheck
                    ? checkAllStataus.hasChecked
                    : checkAllStataus.noChecked;
            }
        }
    }
    getFixHead() {
        const { checkbox, children } = this.props;
        const curPageCheckAll = this.countCurPageTotalStatus();
        const colgroupCom = this.getColGroupCom();
        const checkCom = checkbox ? (React.createElement(CheckBox, { type: "checkbox", changeHandle: this.checkCurPageAll, checked: curPageCheckAll === checkAllStataus.checked, name: "checkAll", hasChecked: curPageCheckAll === checkAllStataus.hasChecked })) : undefined;
        return (React.createElement("table", null,
            colgroupCom,
            React.createElement("thead", null,
                React.createElement("tr", null,
                    React.createElement("th", { key: "order", className: "td-left" },
                        checkCom,
                        "\u5E8F\u53F7"),
                    children))));
    }
    getTableBody() {
        const { curPage, tableData, perNums } = this.state;
        return (React.createElement(ScrollBox, { bindIntiScroll: this.bindScrollMethods, className: "m-fixTabBody" },
            React.createElement("table", null,
                this.getColGroupCom(),
                React.createElement("tbody", null,
                    React.createElement(TabBody, { curPage: curPage, perNums: perNums, selectfn: this.selectedHandle, changeHandle: this.changeState, tableData: tableData, fileObj: this.fieldObj })))));
    }
    render() {
        const { noPageNums, emptyTxt, hasBorder, height } = this.props;
        const { perNums, curPage, tableData } = this.state;
        const mianBody = tableData.size ? (this.getTableBody()) : (React.createElement("div", { className: "m-fixTabBody" },
            React.createElement(Empty, { txt: emptyTxt })));
        const pageSize = !noPageNums && tableData.size ? (React.createElement(PageSize, { changeHandle: this.changeState, curPage: curPage, totalNums: tableData.size, perNums: perNums })) : undefined;
        const borderName = hasBorder ? "g-tab-border" : "";
        const style = height ? { height: height } : undefined;
        return (React.createElement("div", { className: `g-table-wrap ${borderName}`, style: style },
            React.createElement("div", { className: "g-table", ref: this.tableContainer },
                React.createElement("div", { className: "m-fixTabHead " }, this.getFixHead()),
                mianBody,
                pageSize)));
    }
}
Table.defaultProps = {
    defaultSel: "",
    emptyTxt: "当前没有数据！",
};
Table.colItem = ({ width, children, align = "td-left", }) => (React.createElement("th", { style: { width: width }, className: `${align}` }, children));
export default Table;

==> web-10.1.0.tgz: package/lib/myTable/table/index.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from "react";
import * as Immutable from "immutable";
import { Empty } from "../../my-icon/index";
import { CheckBox } from "../../input/index";
import { ScrollBox } from "../../scroll/index";
import PageSize from "../../pagezSize/index";
import TabBody from "./TBody";
var checkAllStataus;
(function (checkAllStataus) {
    checkAllStataus["hasChecked"] = "hasCheck";
    checkAllStataus["checked"] = "checked";
    checkAllStataus["noChecked"] = "noChecked";
})(checkAllStataus || (checkAllStataus = {}));
const tableInitData = (data, defaulSel, idField) => {
    const defaulSelArr = `${defaulSel}`.split(",");
    return Immutable.fromJS(data, (_key, val) => {
        if (Immutable.isKeyed(val)) {
            let obj = val.toOrderedMap();
            const id = val.get(idField);
            const has = defaulSelArr.includes(`${id}`);
            obj = obj.set("checked", has).set("selected", has);
            return obj;
        }
        else {
            return val.toList();
        }
    });
};
const initCurPage = (props, perNums, curOptId) => {
    const { data, idField } = props;
    if (!curOptId) {
        return 1;
    }
    else {
        const index = data.findIndex((val) => String(val[idField]) === String(curOptId));
        const pages = index > -1 ? Math.ceil((index + 1) / perNums) : 1;
        return pages;
    }
};
class Table extends React.PureComponent {
    constructor(props) {
        super(props);
        this.fieldObj = this.initFixObj();
        this.tableContainer = React.createRef();
        this.scrollMethod = undefined;
        this.bindScrollMethods = (methods) => {
            this.scrollMethod = methods;
        };
        this.getSelected = () => {
            const { tableData } = this.state;
            return tableData.filter((val) => val.get("checked"));
        };
        this.checkCurPageAll = (e) => {
            const inpDom = e.currentTarget;
            const checked = inpDom.checked;
            const { tableData, curPage, perNums } = this.state;
            const { noPageNums } = this.props;
            let num;
            if (!noPageNums) {
                const rest = curPage * perNums - tableData.size;
                num = rest > 0 ? perNums - rest : perNums;
            }
            else {
                num = tableData.size;
            }
            this.setState((pre) => {
                let newData = pre.tableData;
                Array.from({ length: num }).forEach((_val, index) => {
                    newData = newData.updateIn([index + (curPage - 1) * perNums], (val) => val.set("checked", checked));
                });
                return {
                    tableData: newData,
                };
            });
        };
        this.changeState = (field, data) => {
            const obj = {
                [field]: data
            };
            if (field === "perNums") {
                obj.curPage = 1;
            }
            this.setState(obj, () => {
                if (["curPage", "perNums"].includes(field) && this.scrollMethod) {
                    this.scrollMethod.initScroll();
                }
            });
        };
        this.selectedHandle = (e) => {
            const index = e.currentTarget.dataset.index;
            const { idField } = this.props;
            this.setState((pre) => {
                const data = pre.tableData;
                const seleted = data.findIndex((val) => val.get("selected"));
                const tableData = seleted === -1
                    ? data.setIn([+index - 1, "selected"], true)
                    : data
                        .setIn([seleted, "selected"], false)
                        .setIn([+index - 1, "selected"], true);
                const curOptId = seleted === -1
                    ? data.getIn([+index - 1, idField])
                    : data.getIn([seleted, idField]);
                return {
                    tableData,
                    curOptId,
                };
            });
        };
        const { data, defaultSel, idField, initSelectVal, bindGetSelectedFn } = props;
        this.state = {
            perNums: 20,
            curPage: this.props.noPageNums ? 1 : initCurPage(props, 20, defaultSel),
            tableData: tableInitData(data, defaultSel, idField),
            preData: data,
            curOptId: defaultSel,
            preInitSelectVal: initSelectVal,
        };
        if (bindGetSelectedFn) {
            bindGetSelectedFn(this.getSelected);
        }
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.data !== preState.preData) {
            const { defaultSel, data, idField, noPageNums } = nextProps;
            const val = preState.curOptId || defaultSel;
            return {
                tableData: tableInitData(data, val, idField),
                curPage: noPageNums ? 1 : initCurPage(nextProps, preState.perNums, preState.curOptId),
                preData: data,
            };
        }
        if (nextProps.initSelectVal !== preState.preInitSelectVal) {
            const { data, idField, initSelectVal, noPageNums } = nextProps;
            const val = initSelectVal ? initSelectVal.id : "";
            return {
                tableData: tableInitData(data, val, idField),
                preInitSelectVal: initSelectVal,
                curPage: noPageNums ? 1 : initCurPage(nextProps, preState.perNums, val),
                curOptId: val,
            };
        }
        else {
            return null;
        }
    }
    componentDidMount() {
        const { defaultSel } = this.props;
        if (defaultSel) {
            this.scrollToSeletItem();
        }
    }
    getSnapshotBeforeUpdate(preProps) {
        const { data, initSelectVal } = this.props;
        if (preProps.data !== data || initSelectVal !== preProps.initSelectVal) {
            return true;
        }
        else {
            return null;
        }
    }
    componentDidUpdate(preProps, _preState, snapshot) {
        if (snapshot) {
            const { defaultSel, initSelectVal } = this.props;
            const val = initSelectVal ? initSelectVal.id : defaultSel;
            if (val) {
                this.scrollToSeletItem();
            }
        }
        if (preProps.data !== this.props.data && this.scrollMethod) {
            this.scrollMethod.initScroll();
        }
    }
    initFixObj() {
        const { idField, checkbox, children: arr, tabField, noPageNums, noOrder } = this.props;
        const column = arr
            .filter((val) => val)
            .map((val) => {
            const _a = val.props, { children } = _a, obj = __rest(_a, ["children"]);
            return obj;
        });
        return {
            idField,
            checkbox,
            column,
            tabField,
            noPageNums,
            noOrder
        };
    }
    scrollToSeletItem() {
        const item = this.tableContainer.current.querySelector(".selected");
        if (!item) {
            return;
        }
        const top = item.offsetTop - 12;
        window.setTimeout(() => {
            this.scrollMethod.scrollToTop(Math.max(0, top));
        }, 10);
    }
    getColGroupCom() {
        const { column, checkbox, noOrder } = this.fieldObj;
        const list = column.map(({ width, field }) => {
            let wObj;
            if (width) {
                const unit = `${width}`.includes("%") ? "" : "px";
                wObj = width ? { width: `${width}` + unit } : undefined;
            }
            else {
                wObj = undefined;
            }
            return React.createElement("col", { key: field, style: wObj });
        });
        const orderWid = checkbox ? 80 : 60;
        const order = noOrder && !checkbox ? undefined : React.createElement("col", { style: { width: orderWid }, key: "order" });
        return (React.createElement("colgroup", null,
            order,
            list));
    }
    getCurPageData() {
        const { tableData, curPage, perNums } = this.state;
        const { noPageNums } = this.props;
        const startIndex = (curPage - 1) * perNums;
        return !noPageNums
            ? tableData.slice(startIndex, startIndex + perNums)
            : tableData;
    }
    countCurPageTotalStatus() {
        const { tableData } = this.state;
        if (tableData.size === 0) {
            return checkAllStataus.noChecked;
        }
        else {
            const curPageData = this.getCurPageData();
            const allCheck = curPageData.every((val) => val.get("checked"));
            if (allCheck) {
                return checkAllStataus.checked;
            }
            else {
                const hasCheck = curPageData.some((val) => val.get("checked"));
                return hasCheck
                    ? checkAllStataus.hasChecked
                    : checkAllStataus.noChecked;
            }
        }
    }
    getFixHead() {
        const { checkbox, children, noOrder } = this.props;
        const curPageCheckAll = this.countCurPageTotalStatus();
        const colgroupCom = this.getColGroupCom();
        const checkCom = checkbox ? (React.createElement(CheckBox, { type: "checkbox", changeHandle: this.checkCurPageAll, checked: curPageCheckAll === checkAllStataus.checked, name: "checkAll", hasChecked: curPageCheckAll === checkAllStataus.hasChecked })) : undefined;
        const order = noOrder && !checkbox ? undefined : (React.createElement("th", { key: "order", className: "td-left" },
            checkCom,
            "\u5E8F\u53F7"));
        return (React.createElement("table", null,
            colgroupCom,
            React.createElement("thead", null,
                React.createElement("tr", null,
                    order,
                    children))));
    }
    getTableBody() {
        const { curPage, tableData, perNums } = this.state;
        return (React.createElement(ScrollBox, { bindIntiScroll: this.bindScrollMethods, className: "m-fixTabBody" },
            React.createElement("table", null,
                this.getColGroupCom(),
                React.createElement("tbody", null,
                    React.createElement(TabBody, { curPage: curPage, perNums: perNums, selectfn: this.selectedHandle, changeHandle: this.changeState, tableData: tableData, fileObj: this.fieldObj })))));
    }
    render() {
        const { noPageNums, emptyTxt, hasBorder, height, tabField } = this.props;
        const { perNums, curPage, tableData } = this.state;
        const mianBody = tableData.size ? (this.getTableBody()) : (React.createElement("div", { className: "m-fixTabBody" }, typeof emptyTxt === "string" || !emptyTxt ? React.createElement(Empty, { txt: emptyTxt }) : emptyTxt(tabField)));
        const pageSize = !noPageNums && tableData.size ? (React.createElement(PageSize, { changeHandle: this.changeState, curPage: curPage, totalNums: tableData.size, perNums: perNums })) : undefined;
        const borderName = hasBorder ? "g-tab-border" : "";
        const style = height ? { height: height } : undefined;
        return (React.createElement("div", { className: `g-table-wrap ${borderName}`, style: style },
            React.createElement("div", { className: "g-table", ref: this.tableContainer },
                React.createElement("div", { className: "m-fixTabHead " }, this.getFixHead()),
                mianBody,
                pageSize)));
    }
}
Table.defaultProps = {
    defaultSel: "",
    emptyTxt: "当前没有数据！",
};
Table.colItem = ({ width, children, align = "td-left", }) => (React.createElement("th", { style: { width: width }, className: `${align}` }, children));
export default Table;
